import readlinePromises from 'readline/promises';
import { existsSync } from 'fs';
import { mkdir, writeFile } from 'fs/promises';

const mapper = (inVal) => {
  const { data } = inVal;
  const outVal = {};

  outVal.tags = {};
  data.tags.forEach(tag => {
    outVal.tags[tag.key] = {
      category: tag.value.category,
      displayName: tag.value.displayName,
    };
  });
  
  return outVal;
};

(async () => {
  const rl = readlinePromises.createInterface(process.stdin, process.stdout);
  let fetchUrl = '';
  try {
    fetchUrl = await rl.question('Enter the URL to fetch from: ');
  } catch (err) {
    console.error('There was an error: ', err);
  } finally {
    if (!fetchUrl) {
      console.log('Invalid URL. Quitting...');
      rl.close();
      return;
    } else if (!fetchUrl.includes('?')) {
      fetchUrl += '?populate[0]=entries&populate[1]=entries.variants&populate[2]=tags&populate[3]=tags.value'
    }
  }

  let destination = '';
  try {
    destination = await rl.question('Enter the directory to save the response (note: start from sites/{your-site-here} for relative pathing): ');
  } catch (err) {
    console.error('There was an error: ', err);
  } finally {
    rl.close();
    if (!destination) {
      console.log('Invalid path. Quitting...');
      return;
    } else {
      if (!existsSync(destination)) {
        await mkdir(destination);
      }
    }
  }

  let res = {};
  try {
    res = await (await fetch(fetchUrl, {
      method: 'GET',
      headers: {
        'Content-Type': 'application/json',
      },
    })).json();
  } catch (err) {
    console.error('There was an error: ', err);
  }

  console.log(res);
  console.log('Writing...');
  try {
    await writeFile(`${destination}/in.json`, JSON.stringify(res, null, 2));
    let val = mapper(res);
    await writeFile(`${destination}/out.json`, JSON.stringify(val, null, 2));
  } catch (err) {
    console.error('There was an error: ', err)
  }
})();
